aboutsummaryrefslogtreecommitdiffstats
path: root/engine/gfx/mon_icons.asm
diff options
context:
space:
mode:
Diffstat (limited to 'engine/gfx/mon_icons.asm')
-rw-r--r--engine/gfx/mon_icons.asm10
1 files changed, 5 insertions, 5 deletions
diff --git a/engine/gfx/mon_icons.asm b/engine/gfx/mon_icons.asm
index dce62c9a..c82e00c0 100644
--- a/engine/gfx/mon_icons.asm
+++ b/engine/gfx/mon_icons.asm
@@ -208,9 +208,9 @@ WriteMonPartySpriteOAMBySpecies:
UnusedPartyMonSpriteFunction:
; This function is unused and doesn't appear to do anything useful. It looks
; like it may have been intended to load the tile patterns and OAM data for
; the mon party sprite associated with the species in [wcf91].
; However, its calculations are off and it loads garbage data.
- ld a, [wcf91]
+ ld a, [wCurPartySpecies]
call GetPartyMonSpriteID
push af
ld hl, vSprites tile $00
@@ -270,9 +270,9 @@ WriteMonPartySpriteOAM:
jp CopyData
GetPartyMonSpriteID:
- ld [wd11e], a
+ ld [wPokedexNum], a
predef IndexToPokedex
- ld a, [wd11e]
+ ld a, [wPokedexNum]
ld c, a
dec a
srl a
@@ -281,7 +281,7 @@ GetPartyMonSpriteID:
ld d, 0
add hl, de
ld a, [hl]
- bit 0, c
+ bit 0, c ; even or odd?
jr nz, .skipSwap
swap a ; use lower nybble if pokedex num is even
.skipSwap
@@ -208,9 +208,9 @@ WriteMonPartySpriteOAMBySpecies:
; This function is unused and doesn't appear to do anything useful. It looks
; like it may have been intended to load the tile patterns and OAM data for
-; the mon party sprite associated with the species in [wcf91].
+; the mon party sprite associated with the species in [wCurPartySpecies].
; However, its calculations are off and it loads garbage data.